@@ -1,21 +1,10 @@
 /*
-   Copyright 2007 David Nolden <david.nolden.kdevelop@art-master.de>
-   Copyright 2008 Niko Sams <niko.sams@gmail.com>
+    SPDX-FileCopyrightText: 2007 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-FileCopyrightText: 2008 Niko Sams <niko.sams@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
+
 #include "navigationwidget.h"
 #include "declarationnavigationcontext.h"
 #include "includenavigationcontext.h"
@@ -26,50 +15,42 @@ namespace Php
 using namespace KDevelop;
 
 NavigationWidget::NavigationWidget(KDevelop::DeclarationPointer declaration, KDevelop::TopDUContextPointer topContext,
-                                   const QString& htmlPrefix, const QString& htmlSuffix,
                                    KDevelop::AbstractNavigationWidget::DisplayHints hints)
     : AbstractNavigationWidget()
-    , m_declaration(declaration)
 {
-    m_topContext = topContext;
     setDisplayHints(hints);
 
     initBrowser(400);
 
     //The first context is registered so it is kept alive by the shared-pointer mechanism
-    m_startContext = NavigationContextPointer(new DeclarationNavigationContext(declaration, m_topContext));
-    m_startContext->setPrefixSuffix(htmlPrefix, htmlSuffix);
-    setContext(m_startContext);
+    auto context = NavigationContextPointer(new DeclarationNavigationContext(declaration, topContext));
+    setContext(context);
 }
 
 NavigationWidget::NavigationWidget(const IncludeItem& includeItem, KDevelop::TopDUContextPointer topContext,
-                                   const QString& htmlPrefix, const QString& htmlSuffix,
                                    KDevelop::AbstractNavigationWidget::DisplayHints hints)
     : AbstractNavigationWidget()
 {
-  m_topContext = topContext;
   setDisplayHints(hints);
 
   initBrowser(200);
 
   //The first context is registered so it is kept alive by the shared-pointer mechanism
-  m_startContext = NavigationContextPointer(new IncludeNavigationContext(includeItem, m_topContext));
-  m_startContext->setPrefixSuffix( htmlPrefix, htmlSuffix );
-  setContext( m_startContext );
+  auto context = NavigationContextPointer(new IncludeNavigationContext(includeItem, topContext));
+  setContext(context);
 }
 
 NavigationWidget::NavigationWidget(TopDUContextPointer topContext, KTextEditor::Cursor position, const QString& constant,
                                    KDevelop::AbstractNavigationWidget::DisplayHints hints)
     : AbstractNavigationWidget()
 {
-  m_topContext = topContext;
   setDisplayHints(hints);
 
   initBrowser(200);
 
   //The first context is registered so it is kept alive by the shared-pointer mechanism
-  m_startContext = NavigationContextPointer(new MagicConstantNavigationContext(topContext, position, constant));
-  setContext( m_startContext );
+  auto context = NavigationContextPointer(new MagicConstantNavigationContext(topContext, position, constant));
+  setContext(context);
 }
 
 QString NavigationWidget::shortDescription(KDevelop::Declaration* declaration)
